@@ -1,5 +1,6 @@
 package App::Mobirc::Model::Channel;
 use Moose;
+use base qw/Class::Accessor::Fast/;
 use Scalar::Util qw/blessed/;
 use Carp;
 use List::MoreUtils qw/any all/;
@@ -10,14 +11,12 @@ has message_log => (
     is      => 'rw',
     isa     => 'ArrayRef',
     default => sub { +[] },
-    auto_deref => 1,
 );
 
 has recent_log => (
     is      => 'rw',
     isa     => 'ArrayRef',
     default => sub { +[] },
-    auto_deref => 1,
 );
 
 has topic => (
@@ -67,7 +66,7 @@ sub add_message {
 sub _add_to_log {
     my ($self, $key, $row) = @_;
 
-    my $log_max = $self->{global_context}->config->{httpd}->{lines} || 20;
+    my $log_max = $self->{global_context}->config->{httpd}->{lines};
 
     push @{$self->{$key}}, $row;
     if ( @{$self->{$key}} > $log_max ) {
@@ -101,7 +100,10 @@ sub clear_unread {
 sub post_command {
     my ($self, $command) = @_;
 
-    $self->{global_context}->run_hook_first('process_command', $command, $self);
+    for my $code (@{$self->{global_context}->get_hook_codes('process_command')}) {
+        my $ret = $code->($self->{global_context}, $command, $self);
+        last if $ret;
+    }
 }
 
 sub recent_log_count {
@@ -109,7 +111,6 @@ sub recent_log_count {
     scalar @{ $self->recent_log };
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 __END__
 
